@@ -169,8 +169,9 @@ def _signin_interactively(
         **kwargs):
     params = pymsalruntime.MSALRuntimeAuthParameters(client_id, authority)
     params.set_requested_scopes(scopes)
-    params.set_redirect_uri("placeholder")  # pymsalruntime 0.1 requires non-empty str,
-        # the actual redirect_uri will be overridden by a value hardcoded by the broker
+    params.set_redirect_uri("https://login.microsoftonline.com/common/oauth2/nativeclient")
+        # This default redirect_uri value is not currently used by the broker
+        # but it is required by the MSAL.cpp to be set to a non-empty valid URI.
     if prompt:
         if prompt == "select_account":
             if login_hint:
